@@ -25,14 +25,13 @@
  */
 
 #include <QApplication>
-#include <QtQml/QQmlDebuggingEnabler>
+#include <QQmlDebuggingEnabler>
 
 #include <QPixmapCache>
 #include <QDebug>
 #include <KAboutData>
 #include <KLocalizedString>
 #include <KDBusService>
-#include <KQuickAddons/QtQuickSettings>
 
 #include <qcommandlineparser.h>
 #include <qcommandlineoption.h>
@@ -41,8 +40,6 @@
 
 #include <Plasma/Theme>
 
-static const char version[] = PROJECT_VERSION;
-
 int main(int argc, char **argv)
 {
     QQmlDebuggingEnabler debugEnabler;
@@ -51,8 +48,10 @@ int main(int argc, char **argv)
     KLocalizedString::setApplicationDomain("plasmoidviewer");
 
     app.setApplicationName(QStringLiteral("plasmoidviewer"));
+    app.setApplicationDisplayName(i18n("Plasmoidviewer"));
     app.setOrganizationDomain(QStringLiteral("kde.org"));
-    app.setApplicationVersion(version);
+    app.setApplicationVersion(PROJECT_VERSION);
+    app.setDesktopFileName(QStringLiteral("org.kde.plasmoidviewer"));
     QApplication::setWindowIcon(QIcon::fromTheme(QStringLiteral("plasma"), app.windowIcon()));
 
     QCommandLineParser parser;
@@ -93,7 +92,6 @@ int main(int argc, char **argv)
     parser.process(app);
 
     KDBusService service(KDBusService::Multiple);
-    KQuickAddons::QtQuickSettings::init();
 
     const QString applet = parser.value("applet");
     if (applet.isEmpty()) {
